Index

A C D E G J K O P Q S T V X 
All Classes and Interfaces|All Packages|Serialized Form

A

ALIAS - Static variable in class org.refcodes.schema.Schema
 

C

COMMENT - Static variable in class org.refcodes.schema.Schema
 

D

DESCRIPTION - Static variable in class org.refcodes.schema.Schema
 

E

EXCEPTION - Static variable in class org.refcodes.schema.Schema
 

G

getAlias() - Method in class org.refcodes.schema.Schema
getChildren() - Method in class org.refcodes.schema.Schema
getDescription() - Method in class org.refcodes.schema.Schema
getType() - Method in class org.refcodes.schema.Schema

J

JsonVisitor - Class in org.refcodes.schema
The JsonVisitor is a SchemaVisitor producing a JSON String when visiting a Schema structure.
JsonVisitor() - Constructor for class org.refcodes.schema.JsonVisitor
JsonVisitor(JsonVisitor.JsonMode) - Constructor for class org.refcodes.schema.JsonVisitor
Constructs a JsonVisitor with JsonVisitor.JsonMode being set accordingly.
JsonVisitor.JsonMode - Enum Class in org.refcodes.schema
The Enum JsonMode.

K

KEY - Static variable in class org.refcodes.schema.Schema
 

O

org.refcodes.schema - module org.refcodes.schema
 
org.refcodes.schema - package org.refcodes.schema
This artifact provides diagnostic functionality for outlining the structure of nested elements, supporting debugging, documentation or specification where needed throughout the REFCODES.ORG toolkit.

P

PLAIN_KEYS - Enum constant in enum class org.refcodes.schema.JsonVisitor.JsonMode
Does not put double quotes around JSON key declarations.

Q

QUOTE_KEYS - Enum constant in enum class org.refcodes.schema.JsonVisitor.JsonMode
Puts double quotes around JSON key declarations.

S

Schema - Class in org.refcodes.schema
A Schema describes a nested data structure (having 0..n Schema children) whilst not being the data structure itself.
Schema(Class<?>, String) - Constructor for class org.refcodes.schema.Schema
Constructs a Schema with the provided arguments.
Schema(Class<?>, String, Schema...) - Constructor for class org.refcodes.schema.Schema
Constructs a Schema with the provided arguments.
Schema(Class<?>, Schema) - Constructor for class org.refcodes.schema.Schema
Constructs a Schema with the provided arguments.
Schema(String, Class<?>) - Constructor for class org.refcodes.schema.Schema
Constructs a Schema with the provided arguments.
Schema(String, Class<?>, String) - Constructor for class org.refcodes.schema.Schema
Constructs a Schema with the provided arguments.
Schema(String, Class<?>, String, Schema...) - Constructor for class org.refcodes.schema.Schema
Constructs a Schema with the provided arguments.
Schema(Schema) - Constructor for class org.refcodes.schema.Schema
Constructs a Schema with the properties of the provided Schema ("copy constructor"),.
Schema(Schema, Schema...) - Constructor for class org.refcodes.schema.Schema
Constructs a Schema with the properties of the provided Schema ("copy constructor"),.
Schemable - Interface in org.refcodes.schema
The Schemable mixin provides means for a data structure to describe itself.
SchemaVisitor<T> - Interface in org.refcodes.schema
Any visitor traversing a Schema instance via the visit(SchemaVisitor) method must accept the results produced by visiting the children of the Schema instance (as of getChildren()) and provide a consolidated result from the children's result and the currently visited Schema instance as of the method SchemaVisitor.visit(Schema, Collection).The SchemaVisitor is a functional interface (similar to the BiFunction interface though as of semantic reasons and documentation means provided as a dedicated interface).

T

toSchema() - Method in interface org.refcodes.schema.Schemable
Returns the Schema representing (describing) the this instance (data structure).
toString() - Method in class org.refcodes.schema.Schema
Uses the JsonVisitor type applied to the visit(SchemaVisitor) method to produce a JSON alike String representation of this Schema instances alongside its children.
toString(Object) - Method in class org.refcodes.schema.JsonVisitor
Hook method for converting a type to an according String.
toString(Object) - Method in class org.refcodes.schema.XmlVisitor
Hook method for converting a type to an according String.
TYPE - Static variable in class org.refcodes.schema.Schema
 

V

VALUE - Static variable in class org.refcodes.schema.Schema
 
valueOf(String) - Static method in enum class org.refcodes.schema.JsonVisitor.JsonMode
Returns the enum constant of this class with the specified name.
values() - Static method in enum class org.refcodes.schema.JsonVisitor.JsonMode
Returns an array containing the constants of this enum class, in the order they are declared.
VERBOSE - Static variable in class org.refcodes.schema.Schema
 
visit(Schema, Collection<String>) - Method in class org.refcodes.schema.JsonVisitor
Produces a result from the provided children's results and the currently visited Schema instance.
visit(Schema, Collection<String>) - Method in class org.refcodes.schema.XmlVisitor
Produces a result from the provided children's results and the currently visited Schema instance.
visit(Schema, Collection<T>) - Method in interface org.refcodes.schema.SchemaVisitor
Produces a result from the provided children's results and the currently visited Schema instance.
visit(SchemaVisitor<T>) - Method in class org.refcodes.schema.Schema
Visits this Schema instance, the provided SchemaVisitor visitor is invoked with the result's of the Schema instance's children (as of visit(SchemaVisitor) and this Schema instance to produce a result.

X

XmlVisitor - Class in org.refcodes.schema
The XmlVisitor is a SchemaVisitor producing an XML String when visiting a Schema structure.
XmlVisitor() - Constructor for class org.refcodes.schema.XmlVisitor
 
A C D E G J K O P Q S T V X 
All Classes and Interfaces|All Packages|Serialized Form