Interface Schemable<OPTS>

Type Parameters:
OPTS - The type of the options being passed creating a Schema.

public interface Schemable<OPTS>
The Schemable mixin provides means for a data structure to describe itself as a Schema. A schema is useful for diagnostics, inspection, documentation, and debugging of an instance's internal structure.
  • Method Summary

    Modifier and Type
    Method
    Description
    Returns a Schema describing this instance for diagnostics and documentation purposes.
    default Schema
    toSchema(OPTS aOptions)
    Returns a Schema describing this instance using the provided options.
  • Method Details

    • toSchema

      Schema toSchema()
      Returns a Schema describing this instance for diagnostics and documentation purposes.
      Returns:
      The schema describing this instance
    • toSchema

      default Schema toSchema(OPTS aOptions)
      Returns a Schema describing this instance using the provided options. The default implementation ignores the options and delegates to toSchema() to remain backwards compatible.
      Parameters:
      aOptions - optional rendering options (may be null depending on the caller's conventions)
      Returns:
      The schema describing this instance