Uses of Class
org.refcodes.schema.Schema
-
Uses of Schema in org.refcodes.schema
Fields in org.refcodes.schema declared as SchemaModifier and TypeFieldDescriptionprotected Schema[]Schema._childrenOptional child schemas representing the nested structure (aggregation).Methods in org.refcodes.schema that return SchemaModifier and TypeMethodDescriptionSchema.Builder.build()Builds theSchemainstance.Schema[]Schema.getChildren()Schemable.toSchema()Returns aSchemadescribing this instance for diagnostics and documentation purposes.default SchemaReturns aSchemadescribing this instance using the provided options.Methods in org.refcodes.schema with parameters of type SchemaModifier and TypeMethodDescriptionVisits the givenSchemainstance and returns the produced result.Visits the givenSchemainstance and returns the produced result.Visits the givenSchemainstance and returns the produced result.Visits the givenSchemainstance and returns the produced result.Visits the givenSchemainstance and returns the produced result.Schema.Builder.withAddChild(Schema aChild) Adds the given child to the current children list.Schema.Builder.withAddChildren(Schema... aChildren) Adds the given children to the current children list.Schema.Builder.withChildren(Schema... aChildren) Replaces the current children with the given collection.Schema.Builder.withSchema(Schema aSchema) Sets a base schema from which options may be copied when building.Method parameters in org.refcodes.schema with type arguments of type SchemaModifier and TypeMethodDescriptionSchema.Builder.withAddChildren(Collection<? extends Schema> aChildren) Adds the given children to the current children list.Schema.Builder.withChildren(Collection<? extends Schema> aChildren) Replaces the current children with the given collection.