Uses of Package
org.refcodes.schema
-
Classes in org.refcodes.schema used by org.refcodes.schemaClassDescriptionThe Enum JsonMode.Any visitor traversing a
Schemainstance via thevisit(SchemaVisitor)method must accept the results produced by visiting the children of theSchemainstance (as ofgetChildren()) and provide a consolidated result from the children's result and the currently visitedSchemainstance as of the methodSchemaVisitor.visit(Schema, Collection).TheSchemaVisitoris a functional interface (similar to theBiFunctioninterface though as of semantic reasons and documentation means provided as a dedicated interface).