All Classes and Interfaces

Class
Description
The JsonVisitor is a SchemaVisitor producing a JSON String when visiting a Schema structure.
The Enum JsonMode.
The PlantUmlVisitor is a SchemaVisitor producing a PlantUML object diagram when visiting a Schema structure.
A Schema is a lightweight, recursive description of an object graph.
Builder for creating Schema instances.
The Schemable mixin provides means for a data structure to describe itself as a Schema.
Predefined schema notations backed by SchemaVisitor implementations.
SchemaOptions represents a set of options influencing how a Schemable instance renders its Schema.
Builder for creating SchemaOptions instances.
A SchemaVisitor traverses a Schema tree and produces a consolidated result.
The XmlVisitor is a SchemaVisitor producing an XML String when visiting a Schema structure.