All Classes and Interfaces

Class
Description
The JsonVisitor is a SchemaVisitor producing a JSON String when visiting a Schema structure.
The Enum JsonMode.
A Schema describes a nested data structure (having 0..n Schema children) whilst not being the data structure itself.
The Schemable mixin provides means for a data structure to describe itself.
Any visitor traversing a Schema instance via the visit(SchemaVisitor) method must accept the results produced by visiting the children of the Schema instance (as of getChildren()) and provide a consolidated result from the children's result and the currently visited Schema instance as of the method SchemaVisitor.visit(Schema, Collection).The SchemaVisitor is a functional interface (similar to the BiFunction interface though as of semantic reasons and documentation means provided as a dedicated interface).
The XmlVisitor is a SchemaVisitor producing an XML String when visiting a Schema structure.