Index
All Classes and Interfaces|All Packages|Serialized Form
A
C
D
- DESCRIPTION - Static variable in class org.refcodes.schema.Schema
E
G
- getAlias() - Method in class org.refcodes.schema.Schema
- getChildren() - Method in class org.refcodes.schema.Schema
- getDescription() - Method in class org.refcodes.schema.Schema
- getType() - Method in class org.refcodes.schema.Schema
J
- JsonVisitor - Class in org.refcodes.schema
- JsonVisitor() - Constructor for class org.refcodes.schema.JsonVisitor
- JsonVisitor(JsonVisitor.JsonMode) - Constructor for class org.refcodes.schema.JsonVisitor
-
Constructs a
JsonVisitorwithJsonVisitor.JsonModebeing set accordingly. - JsonVisitor.JsonMode - Enum Class in org.refcodes.schema
-
The Enum JsonMode.
K
O
- org.refcodes.schema - module org.refcodes.schema
- org.refcodes.schema - package org.refcodes.schema
-
This artifact provides diagnostic functionality for outlining the structure of nested elements, supporting debugging, documentation or specification where needed throughout the
REFCODES.ORGtoolkit.
P
- PLAIN_KEYS - Enum constant in enum class org.refcodes.schema.JsonVisitor.JsonMode
-
Does not put double quotes around JSON key declarations.
Q
- QUOTE_KEYS - Enum constant in enum class org.refcodes.schema.JsonVisitor.JsonMode
-
Puts double quotes around JSON key declarations.
S
- Schema - Class in org.refcodes.schema
- Schema(Class<?>, String) - Constructor for class org.refcodes.schema.Schema
-
Constructs a
Schemawith the provided arguments. - Schema(Class<?>, String, Schema...) - Constructor for class org.refcodes.schema.Schema
-
Constructs a
Schemawith the provided arguments. - Schema(Class<?>, Schema) - Constructor for class org.refcodes.schema.Schema
-
Constructs a
Schemawith the provided arguments. - Schema(String, Class<?>) - Constructor for class org.refcodes.schema.Schema
-
Constructs a
Schemawith the provided arguments. - Schema(String, Class<?>, String) - Constructor for class org.refcodes.schema.Schema
-
Constructs a
Schemawith the provided arguments. - Schema(String, Class<?>, String, Schema...) - Constructor for class org.refcodes.schema.Schema
-
Constructs a
Schemawith the provided arguments. - Schema(Schema) - Constructor for class org.refcodes.schema.Schema
- Schema(Schema, Schema...) - Constructor for class org.refcodes.schema.Schema
- Schemable - Interface in org.refcodes.schema
-
The
Schemablemixin provides means for a data structure to describe itself. - SchemaVisitor<T> - Interface in org.refcodes.schema
-
Any visitor traversing a
Schemainstance via thevisit(SchemaVisitor)method must accept the results produced by visiting the children of theSchemainstance (as ofgetChildren()) and provide a consolidated result from the children's result and the currently visitedSchemainstance as of the methodSchemaVisitor.visit(Schema, Collection).TheSchemaVisitoris a functional interface (similar to theBiFunctioninterface though as of semantic reasons and documentation means provided as a dedicated interface).
T
- toSchema() - Method in interface org.refcodes.schema.Schemable
-
Returns the
Schemarepresenting (describing) the this instance (data structure). - toString() - Method in class org.refcodes.schema.Schema
-
Uses the
JsonVisitortype applied to thevisit(SchemaVisitor)method to produce a JSON alikeStringrepresentation of thisSchemainstances alongside its children. - toString(Object) - Method in class org.refcodes.schema.JsonVisitor
-
Hook method for converting a type to an according
String. - toString(Object) - Method in class org.refcodes.schema.XmlVisitor
-
Hook method for converting a type to an according
String. - TYPE - Static variable in class org.refcodes.schema.Schema
V
- VALUE - Static variable in class org.refcodes.schema.Schema
- valueOf(String) - Static method in enum class org.refcodes.schema.JsonVisitor.JsonMode
-
Returns the enum constant of this class with the specified name.
- values() - Static method in enum class org.refcodes.schema.JsonVisitor.JsonMode
-
Returns an array containing the constants of this enum class, in the order they are declared.
- VERBOSE - Static variable in class org.refcodes.schema.Schema
- visit(Schema, Collection<String>) - Method in class org.refcodes.schema.JsonVisitor
-
Produces a result from the provided children's results and the currently visited
Schemainstance. - visit(Schema, Collection<String>) - Method in class org.refcodes.schema.XmlVisitor
-
Produces a result from the provided children's results and the currently visited
Schemainstance. - visit(Schema, Collection<T>) - Method in interface org.refcodes.schema.SchemaVisitor
-
Produces a result from the provided children's results and the currently visited
Schemainstance. - visit(SchemaVisitor<T>) - Method in class org.refcodes.schema.Schema
-
Visits this
Schemainstance, the providedSchemaVisitorvisitor is invoked with the result's of theSchemainstance's children (as ofvisit(SchemaVisitor)and thisSchemainstance to produce a result.
X
- XmlVisitor - Class in org.refcodes.schema
- XmlVisitor() - Constructor for class org.refcodes.schema.XmlVisitor
All Classes and Interfaces|All Packages|Serialized Form