Class Schema

java.lang.Object
All Implemented Interfaces:
Serializable, Cloneable, Map<String,Object>, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.ChildrenAccessor<Schema[]>, org.refcodes.mixin.DescriptionAccessor, org.refcodes.mixin.TypeAccessor

public class Schema extends HashMap<String,Object> implements org.refcodes.mixin.ChildrenAccessor<Schema[]>, org.refcodes.mixin.TypeAccessor, org.refcodes.mixin.AliasAccessor, org.refcodes.mixin.DescriptionAccessor
A Schema describes a nested data structure (having 0..n Schema children) whilst not being the data structure itself. A documentation in JSON or XML notation can be produced from a Schema instance for debugging or diagnostic purposes (see JsonVisitor as well as XmlVisitor) by invoking the visit(SchemaVisitor) method (also custom SchemaVisitor classes my be programmed).For description purposes, any descriptive attribute can be added as a key with the according value, as a Schema extends the Map interface. The Schema is a useful base class when implementing a package's Schema type. By default it's toString() method produces a JSON alike String representation of this Schema instances alongside its children by uses the JsonVisitor type applied to the visit(SchemaVisitor) method.
See Also: