- Type Parameters:
T- the generic type
- All Known Implementing Classes:
JsonVisitor,XmlVisitor
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
Any visitor traversing a
Schema instance via the
Schema.visit(SchemaVisitor) method must accept the results produced
by visiting the children of the Schema instance (as of
Schema.getChildren()) and provide a consolidated result from the
children's result and the currently visited Schema instance as of the
method visit(Schema, Collection).The SchemaVisitor is a
functional interface (similar to the BiFunction interface though as
of semantic reasons and documentation means provided as a dedicated
interface).-
Method Summary
-
Method Details
-
visit
Produces a result from the provided children's results and the currently visitedSchemainstance.- Parameters:
aSchema- TheSchemainstance to be visited.aResults- The results produced by thisSchemaVisitorinstance when having been invoked for theSchemainstance's children ornullif the visitedSchemainstance does not have any children.- Returns:
- The accordingly produced result of the
SchemaVisitorinstance.
-