JavaScript is disabled on your browser.
Skip navigation links
Module
Package
Class
Use
Tree
Index
Help
Summary:
Nested |
Field |
Constr |
Method
Detail:
Field |
Constr |
Method
SEARCH:
Module
org.refcodes.schema
Package
org.refcodes.schema
Interface Schemable
public interface
Schemable
The
Schemable
mixin provides means for a data structure to describe itself. A
Schema
is useful for diagnostics when analyzing, documenting or debugging an instance's internal structure.
Method Summary
All Methods
Instance Methods
Abstract Methods
Modifier and Type
Method
Description
Schema
toSchema
()
Returns the
Schema
representing (describing) the this instance (data structure).
Method Details
toSchema
Schema
toSchema
()
Returns the
Schema
representing (describing) the this instance (data structure).
Returns:
The
Schema
representation (describing) this instance (data structure) for debugging and verification (or documentation) purposes.