Package org.refcodes.schema
package org.refcodes.schema
This artifact provides diagnostic functionality for outlining the structure
of nested elements, supporting debugging, documentation or specification
where needed throughout the
REFCODES.ORG toolkit. Any class
implementing the Schemable interface must provide
a Schema tree outlining its internal construction
which can be used for diagnostics by printing the structure in a JSON alike
notation (as of Schema.toString() method)
The types with which this artifact's codes work usually are represented by interfaces (as of interface based programming).
Please refer to the refcodes-schema: Canonical runtime diagnostics and visitor-based reports documentation for an up-to-date and detailed description on the usage of this artifact.
-
ClassDescriptionThe Enum JsonMode.The
PlantUmlVisitoris aSchemaVisitorproducing a PlantUML object diagram when visiting aSchemastructure.Schema.Builderto buildSchema.TheSchemablemixin provides means for a data structure to describe itself.TheSchemaNotationenumeration provides defaultSchemaVisitorinstances producing aStringrepresentation of the according notation for aSchemainstance in question by invoking the #visit(Schema) method.A visitor traverses aSchemainstance recursively by having itsSchemaVisitor.visit(Schema)method invoked via theSchema.visit(SchemaVisitor).