Module org.refcodes.schema
Package org.refcodes.schema
package org.refcodes.schema
This artifact provides diagnostic functionality for outlining the structure
of nested elements, supporting debugging, documentation or specification
where needed throughout the
REFCODES.ORG toolkit. Any class
implementing the Schemable interface must provide
a Schema tree outlining its internal construction
which can be used for diagnostics by printing the structure in a JSON alike
notation (as of Schema.toString() method)
The types with which this artifact's codes work usually are represented by interfaces (as of interface based programming).
-
ClassDescriptionThe Enum JsonMode.The
Schemablemixin provides means for a data structure to describe itself.Any visitor traversing aSchemainstance via theSchema.visit(SchemaVisitor)method must accept the results produced by visiting the children of theSchemainstance (as ofSchema.getChildren()) and provide a consolidated result from the children's result and the currently visitedSchemainstance as of the methodSchemaVisitor.visit(Schema, Collection).TheSchemaVisitoris a functional interface (similar to theBiFunctioninterface though as of semantic reasons and documentation means provided as a dedicated interface).